@@ -84,7 +84,7 @@ Beekeeper is a framework for building applications with a microservices architec
 
 =begin HTML
 
-<p><img src="httpa://github.com/jmico/beekeeper/doc/images/beekeeper.svg"/></p>
+<p><img src="https://raw.githubusercontent.com/jmico/beekeeper/master/doc/images/beekeeper.svg"/></p>
 
 =end HTML
 
@@ -106,7 +106,7 @@ B<Benefits of this architecture:>
 
 B<Key characteristics:>
 
-- Broker is a messaging server like RabbitMQ or Apache ActiveMQ.
+- Broker is a messaging server like Apache ActiveMQ or RabbitMQ.
 
 - Broker protocol is STOMP (see the specification at L<https://stomp.github.io/stomp-specification-1.2.html>).
 
@@ -116,7 +116,7 @@ B<Key characteristics:>
 
 - No message persistence in the broker, it just passes on messages.
 
-- No routing logic is defined in the broker, zero configuration is needed.
+- No routing logic is defined in the broker.
 
 - Efficient multicast and unicast notifications.
 
@@ -268,6 +268,8 @@ L<Beekeeper::WorkerPool>, L<Beekeeper::Client>, L<Beekeeper::Worker>.
  
 The source code repository for Beekeeper can be found at L<https://github.com/jmico/beekeeper>
 
+=encoding utf8
+
 =head1 AUTHOR
 
 José Micó, C<jose.mico@gmail.com>
